@@ -39,10 +39,10 @@ public:
     };
 
     ~AbstractModel() override;
-    QHash<int, QByteArray> roleNames() const Q_DECL_FINAL;
-    int rowCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_FINAL;
-    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
-    bool setData(const QModelIndex &index, const QVariant &value, int role) Q_DECL_FINAL;
+    QHash<int, QByteArray> roleNames() const final;
+    int rowCount(const QModelIndex &parent = QModelIndex()) const final;
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
+    bool setData(const QModelIndex &index, const QVariant &value, int role) final;
 
     Q_INVOKABLE int role(const QByteArray &roleName) const;
 
@@ -51,7 +51,7 @@ protected:
     void initRoleNames(const QMetaObject &qobjectMetaObject);
     Context *context() const;
 
-private slots:
+private Q_SLOTS:
     void propertyChanged();
 
 private:
@@ -74,7 +74,7 @@ class CardModel : public AbstractModel
 {
     Q_OBJECT
 public:
-    CardModel(QObject *parent = nullptr);
+    explicit CardModel(QObject *parent = nullptr);
 };
 
 class SinkModel : public AbstractModel
@@ -88,12 +88,12 @@ public:
     };
     Q_ENUMS(ItemRole)
 
-    SinkModel(QObject *parent = nullptr);
+    explicit SinkModel(QObject *parent = nullptr);
     Sink *defaultSink() const;
     Sink *preferredSink() const;
-    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
 
-signals:
+Q_SIGNALS:
     void defaultSinkChanged();
     void preferredSinkChanged();
 
@@ -110,7 +110,7 @@ class SinkInputModel : public AbstractModel
 {
     Q_OBJECT
 public:
-    SinkInputModel(QObject *parent = nullptr);
+    explicit SinkInputModel(QObject *parent = nullptr);
 };
 
 class SourceModel : public AbstractModel
@@ -123,11 +123,11 @@ public:
     };
     Q_ENUMS(ItemRole)
 
-    SourceModel(QObject *parent = nullptr);
+    explicit SourceModel(QObject *parent = nullptr);
     Source *defaultSource() const;
-    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
 
-signals:
+Q_SIGNALS:
     void defaultSourceChanged();
 };
 
@@ -135,21 +135,21 @@ class SourceOutputModel : public AbstractModel
 {
     Q_OBJECT
 public:
-    SourceOutputModel(QObject *parent = nullptr);
+    explicit SourceOutputModel(QObject *parent = nullptr);
 };
 
 class StreamRestoreModel : public AbstractModel
 {
     Q_OBJECT
 public:
-    StreamRestoreModel(QObject *parent = nullptr);
+    explicit StreamRestoreModel(QObject *parent = nullptr);
 };
 
 class ModuleModel : public AbstractModel
 {
     Q_OBJECT
 public:
-    ModuleModel(QObject *parent = nullptr);
+    explicit ModuleModel(QObject *parent = nullptr);
 };
 
 } // QPulseAudio
