@@ -70,8 +70,13 @@ void Plugin::registerTypes(const char* uri)
             Q_UNUSED(jsEngine);
             return new MicrophoneIndicator();
     });
-
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
     qmlRegisterType<QPulseAudio::Client>();
     qmlRegisterType<QPulseAudio::Sink>();
     qmlRegisterType<QPulseAudio::Source>();
+#else
+    qmlRegisterAnonymousType<QPulseAudio::Client>(uri, 1);
+    qmlRegisterAnonymousType<QPulseAudio::Sink>(uri, 1);
+    qmlRegisterAnonymousType<QPulseAudio::Source>(uri, 1);
+#endif
 }
