@@ -27,9 +27,9 @@ class VolumeOSD : public QObject
 {
     Q_OBJECT
 public:
-    VolumeOSD(QObject *parent = nullptr);
+    explicit VolumeOSD(QObject *parent = nullptr);
 
-public slots:
+public Q_SLOTS:
     void show(int percent);
     void showMicrophone(int percent);
     void showText(const QString &iconName, const QString &text);
